@@ -9,15 +9,16 @@ class AbstractTekstiTv : public QObject
     Q_OBJECT
 public:
     virtual void getTekstiTv(int page, int subPage) = 0;
-
+    virtual void getTekstiTv(QString url) = 0;
     virtual QString imageUrl() = 0;
+    virtual QString subImageUrl() = 0;
     virtual QString predictionUrl() = 0;
     virtual QString subPredictionUrl() = 0;
     virtual QString nextPrediction() = 0;
     virtual QString previousPrediction() = 0;
     virtual QString nextSubPrediction() = 0;
     virtual QString previousSubPrediction() = 0;
-    virtual int pad() = 0;
+    virtual int startPage() = 0;
 
 public slots:
 
@@ -45,7 +46,7 @@ QString m_previousSubPrediction;
 
 int m_page;
 int m_subPage;
-
+int m_startPage;
 };
 
 #endif // ABSTRACTTEKSTITV_H
