@@ -8,24 +8,26 @@ class CommonTekstiTv : public AbstractTekstiTv
 {
     Q_OBJECT
 public:
-    CommonTekstiTv(QString imageUrl, QString predictionUrl, QString subPredictionUrl,
+    CommonTekstiTv(QString imageUrl, QString subImageUrl, QString predictionUrl, QString subPredictionUrl,
                    QString prevPrediction, QString nextPrediction,
-                   QString prevSubPrediction, QString nextSubPrediction, int pad);
+                   QString prevSubPrediction, QString nextSubPrediction, int startPage);
 
     QString imageUrl();
+    QString subImageUrl();
     QString predictionUrl();
     QString subPredictionUrl();
     QString nextPrediction();
     QString previousPrediction();
     QString nextSubPrediction();
     QString previousSubPrediction();
-    int pad();
+    int startPage();
 
 public slots:
 
  void getPrediction(int increment);
  void getSubPrediction(int increment);
  void getTekstiTv(int page, int subPage);
+ void getTekstiTv(QString url);
 
 private slots:
 
@@ -45,6 +47,7 @@ private:
 private:
 
 QString m_imageUrl;
+QString m_subImageUrl;
 QString m_predictionUrl;
 QString m_subPredictionUrl;
 
@@ -54,7 +57,7 @@ QString m_previousPrediction;
 QString m_nextSubPrediction;
 QString m_previousSubPrediction;
 
-int m_pad;
+int m_startPage;
 int m_page;
 int m_subPage;
 
