@@ -15,7 +15,7 @@
 //#include <mce/dbus-names.h>
 #endif
 
-TekstiTv::TekstiTv(QWidget *parent) : QWidget(parent), sites(new QMap<QString, AbstractTekstiTv*>())
+TekstiTv::TekstiTv(QWidget *parent) : QWidget(parent), sites(new QMap<QString, AbstractTekstiTv*>()), siteKeys()
 {
     this->parent = parent;
     //addRotationAwareness();
@@ -23,17 +23,19 @@ TekstiTv::TekstiTv(QWidget *parent) : QWidget(parent), sites(new QMap<QString, A
     readSites();
     if (sites->size() < 1) {
         qDebug() << "adding default site";
-            site = new CommonTekstiTv(QString("http://www.yle.fi/tekstitv/images/P[page]_[subpage].gif"),
+        site = new CommonTekstiTv(QString("http://www.yle.fi/tekstitv/images/P[page]_[2:subpage].gif"),
+                                 QString("http://www.yle.fi/tekstitv/images/P[page]_[2:subpage].gif"),
                                       QString("http://www.yle.fi/tekstitv/txt/P[page]_01.html"),
-                                      QString("http://www.yle.fi/tekstitv/txt/P[page]_[subpage].html"),
+                                      QString("http://www.yle.fi/tekstitv/txt/P[page]_[2:subpage].html"),
                                       QString("<A HREF=\"http://www.yle.fi/tekstitv/txt/P(\\d+)_01.html\">\\[Edellinen sivu\\]</A>"),
                                       QString("<A HREF=\"http://www.yle.fi/tekstitv/txt/P(\\d+)_01.html\">\\[Seuraava sivu\\]</A>"),
                                       QString("<A HREF=\"http://www.yle.fi/tekstitv/txt/P\\d+_(\\d+).html\">\\[Edellinen alasivu\\]</A>"),
-                                      QString("<A HREF=\"http://www.yle.fi/tekstitv/txt/P\\d+_(\\d+).html\">\\[Seuraava alasivu\\]</A>"), 2);
+                                      QString("<A HREF=\"http://www.yle.fi/tekstitv/txt/P\\d+_(\\d+).html\">\\[Seuraava alasivu\\]</A>"), 100);
 
             sites->insert("Yle", site);
             writeSites();
     }
+    //qDebug() << "sites read";
     // debug yle
 //
 //    // mtv3
@@ -63,7 +65,7 @@ TekstiTv::TekstiTv(QWidget *parent) : QWidget(parent), sites(new QMap<QString, A
 
     QVBoxLayout *leftLayout = new QVBoxLayout();
 
-    page = 100;
+    page = site->startPage();
     subPage = 1;
 
     imageWidth = 510;
@@ -91,6 +93,7 @@ TekstiTv::TekstiTv(QWidget *parent) : QWidget(parent), sites(new QMap<QString, A
     //#ifdef Q_WS_MAEMO_5
     createFingerKeys();
     //#endif
+    //qDebug() << "tekstitv constructor in the end, getting first site"
     site->getTekstiTv(page, subPage);
 }
 
@@ -175,9 +178,10 @@ void TekstiTv::siteSelected(QString siteName) {
     site = sites->value(siteName);
     connect(site, SIGNAL(receivedTekstiTv(QPixmap*)), this, SLOT(receivedTekstiTv(QPixmap*)));
     connect(site, SIGNAL(receivedPrediction(int, int)), this, SLOT(receivedPrediction(int, int)));
-    page = 100;
+    page = site->startPage();
     lblPageNumber->setText(QString::number(page));
     subPage = 1;
+    //lblImageTekstiTv->setImage();
     //site->getTekstiTv(page, subPage);
 }
 
@@ -189,19 +193,19 @@ void TekstiTv::resizeRequestReceived() {
             lblPageNumber->hide();
             numberGroup->hide();
             parent->showFullScreen();
-            qDebug() << "making full screen";
+            //qDebug() << "making full screen";
             QPixmap scaledMap = imageData->scaled(bigImageWidth, bigImageHeight, Qt::KeepAspectRatio, Qt::SmoothTransformation);
-            qDebug() << "full screen ready";
+            //qDebug() << "full screen ready";
             lblImageTekstiTv->setPixmap(scaledMap);
         } else {
-            qDebug() << "coming out of full screen";
+            //qDebug() << "coming out of full screen";
             screen = FullScreenOff;
             lblPageNumber->show();
             numberGroup->show();
             QPixmap scaledMap = imageData->scaled(imageWidth, imageHeight, Qt::KeepAspectRatio, Qt::SmoothTransformation);
             lblImageTekstiTv->setPixmap(scaledMap);
             parent->showNormal();
-            qDebug() << "coming out of full screen ready";
+            //qDebug() << "coming out of full screen ready";
         }
     #endif
 }
@@ -307,21 +311,24 @@ void TekstiTv::readSites() {
     settings.setArrayIndex(i);
     QString siteName = settings.value("siteName").toString();
     QString imageUrl = settings.value("imageUrl").toString();
+    QString subImageUrl = settings.value("subImageUrl", imageUrl).toString();
     QString predictionUrl = settings.value("predictionUrl").toString();
     QString subPredictionUrl = settings.value("subPredictionUrl").toString();
     QString previousPrediction = settings.value("previousPrediction").toString();
     QString nextPrediction = settings.value("nextPrediction").toString();
     QString previousSubPrediction = settings.value("previousSubPrediction").toString();
     QString nextSubPrediction = settings.value("nextSubPrediction").toString();
-    int pad = settings.value("pad").toInt();
-    CommonTekstiTv *common = new CommonTekstiTv(imageUrl, predictionUrl, subPredictionUrl,
+    int startPage = settings.value("startPage").toInt();
+    CommonTekstiTv *common = new CommonTekstiTv(imageUrl, subImageUrl, predictionUrl, subPredictionUrl,
                                                                             previousPrediction, nextPrediction,
-                                                                            previousSubPrediction, nextSubPrediction, pad);
+                                                                            previousSubPrediction, nextSubPrediction, startPage);
     sites->insert(siteName, common);
+    siteKeys.append(siteName);
     //site = common;  // debug just one
  }
  settings.endArray();
- site = sites->value("Yle");
+ //site = sites->value("Yle");
+ site = sites->value(siteKeys[0]);
 }
 
 void TekstiTv::writeSites() {
@@ -337,13 +344,14 @@ void TekstiTv::writeSites() {
         settings.setArrayIndex(index);
         settings.setValue("siteName", siteName);
         settings.setValue("imageUrl", tempSite->imageUrl());
+        settings.setValue("subImageUrl", tempSite->subImageUrl());
         settings.setValue("predictionUrl", tempSite->predictionUrl());
         settings.setValue("subPredictionUrl", tempSite->subPredictionUrl());
         settings.setValue("previousPrediction", tempSite->previousPrediction());
         settings.setValue("nextPrediction", tempSite->nextPrediction());
         settings.setValue("previousSubPrediction", tempSite->previousSubPrediction());
         settings.setValue("nextSubPrediction", tempSite->nextSubPrediction());
-        settings.setValue("pad", tempSite->pad());        
+        settings.setValue("startPage", tempSite->startPage());
         index++;
      }
      qDebug() << QString("Wrote %1 sites to the config").arg(index);
